@@ -1266,7 +1266,7 @@ impl<'a, I: Tokens> Parser<I> {
         // as a pattern instead of reparsing)
         while !eof!(self) && !is!(self, ')') {
             if first {
-                if is!(self, "async") {
+                if is!(self, "async") && !peeked_is!(self, ',') {
                     // https://github.com/swc-project/swc/issues/410
                     self.state.potential_arrow_start = Some(cur_pos!(self));
                     let expr = self.parse_assignment_expr()?;
